[![tests](https://github.com/relf/egobox/workflows/tests/badge.svg)](https://github.com/relf/egobox/actions?query=workflow%3Atests)

# egobox

Rust toolbox dedicated to algorithms related to efficient global optimization and freely inspired from [SMT](https://github.com/SMTorg/smt). 
